@@ -30,7 +30,7 @@ def transpose(lst, shape):
 def convert_all(lst, to=list, exclude=(str,)):
     for item in lst:
         if hasattr(item, '__iter__') and not isinstance(item, exclude):
-            yield to(convert_all(item))
+            yield to(convert_all(item, to, exclude))
         else:
             yield item
             
